pub(crate) fn parse_codegen_backends(
backends: Vec<String>,
section: &str,
) -> Vec<CodegenBackendKind>Expand description
FIXME(Zalathar): This is partly redundant with the parsing code in CodegenBackendKind.
pub(crate) fn parse_codegen_backends(
backends: Vec<String>,
section: &str,
) -> Vec<CodegenBackendKind>FIXME(Zalathar): This is partly redundant with the parsing code in CodegenBackendKind.